"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
const vscode_languageserver_1 = require("vscode-languageserver");
const logging_1 = require("./logging");
function newConnection(input, output, options) {
    const logger = options.logger || new logging_1.NoopLogger();
    const reader = new vscode_jsonrpc_1.StreamMessageReader(input);
    const listen = reader.listen.bind(reader);
    reader.listen = (callback) => {
        listen((message) => {
            if (options.trace) {
                logger.log('-->', message);
            }
            callback(message);
        });
    };
    const writer = new vscode_jsonrpc_1.StreamMessageWriter(output);
    const write = writer.write.bind(writer);
    writer.write = (message) => {
        if (options.trace) {
            logger.log('<--', message);
        }
        write(message);
    };
    const connection = vscode_languageserver_1.createConnection(reader, writer);
    // Remove vscode-languageserver's stream listeners that kill the process if the stream is closed
    input.removeAllListeners('end');
    input.removeAllListeners('close');
    output.removeAllListeners('end');
    output.removeAllListeners('close');
    return connection;
}
exports.newConnection = newConnection;
/**
 * Registers all method implementations of a LanguageHandler on a connection
 */
function registerLanguageHandler(connection, handler) {
    connection.onInitialize((params, token) => handler.initialize(params, token));
    connection.onShutdown(() => handler.shutdown());
    // textDocument
    connection.onDidOpenTextDocument(params => handler.didOpen(params));
    connection.onDidChangeTextDocument(params => handler.didChange(params));
    connection.onDidSaveTextDocument(params => handler.didSave(params));
    connection.onDidCloseTextDocument(params => handler.didClose(params));
    connection.onReferences((params, token) => handler.getReferences(params, token));
    connection.onHover((params, token) => handler.getHover(params, token));
    connection.onDefinition((params, token) => handler.getDefinition(params, token));
    connection.onDocumentSymbol((params, token) => handler.getDocumentSymbol(params, token));
    connection.onCompletion((params, token) => handler.getCompletions(params, token));
    connection.onRequest('textDocument/xdefinition', (params, token) => handler.getXdefinition(params, token));
    // workspace
    connection.onWorkspaceSymbol((params, token) => handler.getWorkspaceSymbols(params, token));
    connection.onRequest('workspace/xreferences', (params, token) => handler.getWorkspaceReference(params, token));
    connection.onRequest('workspace/xpackages', (params, token) => handler.getPackages(params, token));
    connection.onRequest('workspace/xdependencies', (params, token) => handler.getDependencies(params, token));
}
exports.registerLanguageHandler = registerLanguageHandler;
//# sourceMappingURL=connection.js.map