import { IConnection } from 'vscode-languageserver';
import { TraceOptions } from './connection';
import { LanguageHandler } from './lang-handler';
import { Logger, StdioLogger } from './logging';
export interface ServeOptions extends TraceOptions {
    clusterSize: number;
    lspPort: number;
}
/**
 * Creates a Logger prefixed with master or worker ID
 *
 * @param logger An optional logger to wrap, e.g. to write to a logfile. Defaults to STDIO
 */
export declare function createClusterLogger(logger?: StdioLogger): Logger;
/**
 * Starts up a cluster of worker processes that listen on the same TCP socket.
 * Crashing workers are restarted automatically.
 *
 * @param options
 * @param createLangHandler Factory function that is called for each new connection
 */
export declare function serve(options: ServeOptions, createLangHandler: (connection: IConnection) => LanguageHandler): Promise<void>;
